@extends ('layouts.template')

@section('content')
<div class="p-3">
    <div class="m-0 mt-4">
        <div class="row mcp-theme-1" id="pro-dashboard-container" v-cloak>
            <div class="col-md-3 mcp-theme-1">
                <div class="mb-4">
                    <div class="pro-dashboard-inline-calendar"></div>
                </div>
                <div class="card mb-4">
                    <div class="card-header pl-2">
                        <strong>
                            <i class="fas fa-chart-bar"></i>
                            Key Numbers
                        </strong>
                    </div>
                    <div class="card-body p-0">
                        <table class="table table-condensed table-bordered m-0">
                            <tbody>
                                <tr>
                                    <th class="px-2 text-center">{{$keyNumbers['totalPatients']}}</th>
                                    <th class="pl-2"><a href="/patients">Total patients</a></th>
                                </tr>
                                <tr>
                                    <th class="px-2 text-center">{{$keyNumbers['patientsNotSeenYet']}}</th>
                                    <th class="pl-2"><a href="/patients/not-yet-seen">Patients I have not seen yet</a></th>
                                </tr>
                                <tr>
                                    <th class="px-2 text-center">{{$keyNumbers['pendingBillsToSign']}}</th>
                                    <th class="pl-2"><a href="/practice-management/bills/not-yet-signed">Pending bills to sign</a></th>
                                </tr>
                                <tr>
                                    <th class="px-2 text-center">{{$keyNumbers['pendingNotesToSign']}}</th>
                                    <th class="pl-2"><a href="/practice-management/notes/not-yet-signed">Pending notes to sign</a></th>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
                <div class="card mt-3">
                    <div class="card-header">
                        <strong>
                            Reimbursement
                        </strong>
                    </div>
                    <div class="card-body p-0">
                        <table class="table table-condensed table-bordered m-0">
                            <tbody>
                                <tr>
                                    <th class="px-2">{{$reimbursement['currentBalance']}}</th>
                                    <th class="pl-2"><a href="/practice-management/financial-transactions">Current balance</a></th>
                                </tr>
                                <tr>
                                    <th class="px-2">{{friendly_date_time($reimbursement['nextPaymentDate'], false)}}</th>
                                    <th class="pl-2">Next Payment Date</th>
                                </tr>
                                <tr>
                                    <th class="px-2">{{$reimbursement['nextPaymentAmount']}}</th>
                                    <th class="pl-2">Next Payment Amount</th>
                                </tr>
                                <tr>
                                    <th class="px-2">{{$reimbursement['lastPayment']}}</th>
                                    <th class="pl-2"><a href="/practice-management/financial-transactions">Last payment</a></th>
                                </tr>
                                <tr>
                                    <th class="px-2">{{friendly_date_time($reimbursement['lastPaymentDate'], false)}}</th>
                                    <th class="pl-2"><a href="/practice-management/financial-transactions">Last payment date</a></th>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
            <div class="col-md-9">
                <div class="d-flex align-items-center mb-2">
                    <b class="large">@{{ selectedDate }}</b>
                    <div class="ml-auto">Tabs</div>
                </div>
                <div v-for="event in events" class="align-items-start p-3 border" :class="event.dateYMD === selectedDate ? 'd-flex' : 'd-none'">
                    <div class="patient-avatar mr-3">@{{ event.clientInitials }}</div>
                    <div>
                        <div class="font-weight-bold pb-1">
                            @{{ event.clientName }}
                            <span class="small d-inline-block pl-2 text-secondary font-weight-normal">@{{ event.clientSummary }}</span>
                        </div>
                        <div class="pb-1">
                            @{{ event.friendlyStartTime }} - @{{ event.friendlyEndTime }}
                            &nbsp;/&nbsp;
                            <span class="d-inline-block ml- 2 text-secondary font-weight-bold">@{{ event.title }}</span>
                        </div>
                        <div>
                            Status: <b class="text-secondary">@{{ event.status }}</b>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    addMCInitializer('pro-dashboard', function () {
        new Vue({
            el: '#pro-dashboard-container',
            delimiters: ['@{{', '}}'],
            data: {
                selectedDate: '{{ date('Y-m-d') }}',
                selectedStatus: 'CREATED',
                events: {!! json_encode($appointments) !!},
            },
            methods: {
                onDateChange: function (_newDate) {
                    this.highlightDatesWithEvents();
                    this.selectedDate = _newDate;
                    console.log('Showing events for ' + _newDate);
                },
                selectToday: function () {
                    $('.pro-dashboard-inline-calendar table td[data-date]').removeClass('active');
                    $('.pro-dashboard-inline-calendar table td[data-date="{{ $milliseconds }}"]')
                        .addClass('active');
                    this.onDateChange('{{ date('Y-m-d') }}');
                },
                highlightDatesWithEvents: function () {
                    $('.pro-dashboard-inline-calendar table td[data-date]').removeAttr('has-events');
                    for (let i = 0; i < this.events.length; i++) {
                        $('.pro-dashboard-inline-calendar table td[data-date="' + this.events[i].milliseconds + '"]')
                            .attr('has-events', 1);
                    }
                }
            },
            mounted: function () {
                var calendarElem = $('.pro-dashboard-inline-calendar'), self = this;
                calendarElem.datepicker({
                    format: 'yyyy-mm-dd'
                });
                calendarElem.on('changeDate', function () {
                    self.onDateChange(calendarElem.datepicker('getFormattedDate'));
                });
                self.selectToday();
                console.log(this.events)
            }
        });
    });
</script>
@endsection
